ColorTheme & Curses Color Definitions
=====================================

ColorTheme
----------

.. autoclass:: curses_fzf.ColorTheme
   :members:

Color
-----

.. autoclass:: curses_fzf.Color
   :members:
